CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
55 lines
1.3 KiB
Plaintext
55 lines
1.3 KiB
Plaintext
// Copyright (c) Advanced Micro Devices, Inc.
|
|
// SPDX-License-Identifier: MIT
|
|
|
|
/*
|
|
An example to explore LDS bandwidth and bank conflicts, written by Nicholas Curtis [AMD].
|
|
*/
|
|
|
|
#include "common.h"
|
|
|
|
constexpr unsigned max_threads = 256;
|
|
constexpr unsigned nbanks = 32;
|
|
|
|
__global__ void load(int* out, int flag) {
|
|
__shared__ int array[max_threads];
|
|
int index = threadIdx.x;
|
|
// fake a store to the LDS array to avoid unwanted behavior
|
|
if (flag)
|
|
array[max_threads - index] = index;
|
|
__syncthreads();
|
|
int x = array[index];
|
|
if (x == int(-1234567))
|
|
out[threadIdx.x] = x;
|
|
}
|
|
|
|
__global__ void conflicts(int* out, int flag) {
|
|
constexpr unsigned nelements = nbanks * max_threads;
|
|
__shared__ int array[nelements];
|
|
// each thread reads from the same bank
|
|
int index = threadIdx.x * nbanks;
|
|
// fake a store to the LDS array to avoid unwanted behavior
|
|
if (flag)
|
|
array[max_threads - index] = index;
|
|
__syncthreads();
|
|
int x = array[index];
|
|
if (x == int(-1234567))
|
|
out[threadIdx.x] = x;
|
|
}
|
|
|
|
void bandwidth_demo(int N) {
|
|
for (int i = 1; i <= N; ++i)
|
|
load<<<1,i>>>(nullptr, 0);
|
|
hipCheck(hipDeviceSynchronize());
|
|
}
|
|
|
|
void conflicts_demo(int N) {
|
|
for (int i = 1; i <= N; ++i)
|
|
conflicts<<<1,i>>>(nullptr, 0);
|
|
hipCheck(hipDeviceSynchronize());
|
|
}
|
|
|
|
int main() {
|
|
bandwidth_demo(max_threads);
|
|
conflicts_demo(max_threads);
|
|
}
|